# Auto-generated by openrct2-codegen 0.4.2
# OpenRCT2 v0.4.32
# Generated: 2026-03-16T16:33:13.378835+00:00
#
# DO NOT EDIT — regenerate with:
#   openrct2-codegen render --template enums.py --out <path>

from enum import IntEnum, IntFlag

# OpenRCT2 version these enums were generated against.
GENERATED_OPENRCT2_VERSION: str = "v0.4.32"


class PeepThoughtType(IntEnum):
    CANT_AFFORD_RIDE = 0
    SPENT_MONEY = 1
    SICK = 2
    VERY_SICK = 3
    MORE_THRILLING = 4
    INTENSE = 5
    HAVENT_FINISHED = 6
    SICKENING = 7
    BAD_VALUE = 8
    GO_HOME = 9
    GOOD_VALUE = 10
    ALREADY_GOT = 11
    CANT_AFFORD_ITEM = 12
    NOT_HUNGRY = 13
    NOT_THIRSTY = 14
    DROWNING = 15
    LOST = 16
    WAS_GREAT = 17
    QUEUING_AGES = 18
    TIRED = 19
    HUNGRY = 20
    THIRSTY = 21
    TOILET = 22
    CANT_FIND = 23
    NOT_PAYING = 24
    NOT_WHILE_RAINING = 25
    BAD_LITTER = 26
    CANT_FIND_EXIT = 27
    GET_OFF = 28
    GET_OUT = 29
    NOT_SAFE = 30
    PATH_DISGUSTING = 31
    CROWDED = 32
    VANDALISM = 33
    SCENERY = 34
    VERY_CLEAN = 35
    FOUNTAINS = 36
    MUSIC = 37
    BALLOON = 38
    TOY = 39
    MAP = 40
    PHOTO = 41
    UMBRELLA = 42
    DRINK = 43
    BURGER = 44
    CHIPS = 45
    ICE_CREAM = 46
    CANDYFLOSS = 47
    PIZZA = 51
    POPCORN = 53
    HOT_DOG = 54
    TENTACLE = 55
    HAT = 56
    TOFFEE_APPLE = 57
    TSHIRT = 58
    DOUGHNUT = 59
    COFFEE = 60
    CHICKEN = 62
    LEMONADE = 63
    WOW = 67
    WOW2 = 70
    WATCHED = 71
    BALLOON_MUCH = 72
    TOY_MUCH = 73
    MAP_MUCH = 74
    PHOTO_MUCH = 75
    UMBRELLA_MUCH = 76
    DRINK_MUCH = 77
    BURGER_MUCH = 78
    CHIPS_MUCH = 79
    ICE_CREAM_MUCH = 80
    CANDYFLOSS_MUCH = 81
    PIZZA_MUCH = 85
    POPCORN_MUCH = 87
    HOT_DOG_MUCH = 88
    TENTACLE_MUCH = 89
    HAT_MUCH = 90
    TOFFEE_APPLE_MUCH = 91
    TSHIRT_MUCH = 92
    DOUGHNUT_MUCH = 93
    COFFEE_MUCH = 94
    CHICKEN_MUCH = 96
    LEMONADE_MUCH = 97
    PHOTO2 = 104
    PHOTO3 = 105
    PHOTO4 = 106
    PRETZEL = 107
    HOT_CHOCOLATE = 108
    ICED_TEA = 109
    FUNNEL_CAKE = 110
    SUNGLASSES = 111
    BEEF_NOODLES = 112
    FRIED_RICE_NOODLES = 113
    WONTON_SOUP = 114
    MEATBALL_SOUP = 115
    FRUIT_JUICE = 116
    SOYBEAN_MILK = 117
    SUJONGKWA = 118
    SUB_SANDWICH = 119
    COOKIE = 120
    ROAST_SAUSAGE = 124
    PHOTO2_MUCH = 136
    PHOTO3_MUCH = 137
    PHOTO4_MUCH = 138
    PRETZEL_MUCH = 139
    HOT_CHOCOLATE_MUCH = 140
    ICED_TEA_MUCH = 141
    FUNNEL_CAKE_MUCH = 142
    SUNGLASSES_MUCH = 143
    BEEF_NOODLES_MUCH = 144
    FRIED_RICE_NOODLES_MUCH = 145
    WONTON_SOUP_MUCH = 146
    MEATBALL_SOUP_MUCH = 147
    FRUIT_JUICE_MUCH = 148
    SOYBEAN_MILK_MUCH = 149
    SUJONGKWA_MUCH = 150
    SUB_SANDWICH_MUCH = 151
    COOKIE_MUCH = 152
    ROAST_SAUSAGE_MUCH = 156
    HELP = 168
    RUNNING_OUT = 169
    NEW_RIDE = 170
    NICE_RIDE_DEPRECATED = 171
    EXCITED_DEPRECATED = 172
    HERE_WE_ARE = 173
    NONE = 255

class PeepNauseaTolerance(IntEnum):
    NONE = 0
    LOW = 1
    AVERAGE = 2
    HIGH = 3

class PeepState(IntEnum):
    FALLING = 0
    ONE = 1
    QUEUING_FRONT = 2
    ON_RIDE = 3
    LEAVING_RIDE = 4
    WALKING = 5
    QUEUING = 6
    ENTERING_RIDE = 7
    SITTING = 8
    PICKED = 9
    PATROLLING = 10
    MOWING = 11
    SWEEPING = 12
    ENTERING_PARK = 13
    LEAVING_PARK = 14
    ANSWERING = 15
    FIXING = 16
    BUYING = 17
    WATCHING = 18
    EMPTYING_BIN = 19
    USING_BIN = 20
    WATERING = 21
    HEADING_TO_INSPECTION = 22
    INSPECTING = 23

class PeepActionType(IntEnum):
    CHECK_TIME = 0
    EAT_FOOD = 1
    SHAKE_HEAD = 2
    EMPTY_POCKETS = 3
    SITTING_EAT_FOOD = 4
    SITTING_CHECK_WATCH = 4
    SITTING_LOOK_AROUND_LEFT = 5
    SITTING_LOOK_AROUND_RIGHT = 6
    WOW = 7
    THROW_UP = 8
    JUMP = 9
    STAFF_SWEEP = 10
    DROWNING = 11
    STAFF_ANSWER_CALL = 12
    STAFF_ANSWER_CALL2 = 13
    STAFF_CHECK_BOARD = 14
    STAFF_FIX = 15
    STAFF_FIX2 = 16
    STAFF_FIX_GROUND = 17
    STAFF_FIX3 = 18
    STAFF_WATERING = 19
    JOY = 20
    READ_MAP = 21
    WAVE = 22
    STAFF_EMPTY_BIN = 23
    WAVE2 = 24
    TAKE_PHOTO = 25
    CLAP = 26
    DISGUST = 27
    DRAW_PICTURE = 28
    BEING_WATCHED = 29
    WITHDRAW_MONEY = 30
    IDLE = 254
    WALKING = 255

class PeepAnimationType(IntEnum):
    WALKING = 0
    CHECK_TIME = 1
    WATCH_RIDE = 2
    EAT_FOOD = 3
    SHAKE_HEAD = 4
    EMPTY_POCKETS = 5
    HOLD_MAT = 6
    SITTING_IDLE = 7
    SITTING_EAT_FOOD = 8
    SITTING_LOOK_AROUND_LEFT = 9
    SITTING_LOOK_AROUND_RIGHT = 10
    HANGING = 11
    STAFF_MOWER = 12
    WOW = 13
    THROW_UP = 14
    JUMP = 15
    STAFF_SWEEP = 16
    DROWNING = 17
    STAFF_ANSWER_CALL = 18
    STAFF_ANSWER_CALL2 = 19
    STAFF_CHECK_BOARD = 20
    STAFF_FIX = 21
    STAFF_FIX2 = 22
    STAFF_FIX_GROUND = 23
    STAFF_FIX3 = 24
    STAFF_WATERING = 25
    JOY = 26
    READ_MAP = 27
    WAVE = 28
    STAFF_EMPTY_BIN = 29
    WAVE2 = 30
    TAKE_PHOTO = 31
    CLAP = 32
    DISGUST = 33
    DRAW_PICTURE = 34
    BEING_WATCHED = 35
    WITHDRAW_MONEY = 36
    INVALID = 255

class PeepAnimationGroup(IntEnum):
    NORMAL = 0
    ALTERNATE = 1
    ICE_CREAM = 1
    CHIPS = 2
    BURGER = 3
    DRINK = 4
    BALLOON = 5
    CANDYFLOSS = 6
    UMBRELLA = 7
    PIZZA = 8
    POPCORN = 9
    ARMS_CROSSED = 10
    HEAD_DOWN = 11
    NAUSEOUS = 12
    VERY_NAUSEOUS = 13
    REQUIRE_TOILET = 14
    HAT = 15
    HOT_DOG = 16
    TENTACLE = 17
    TOFFEE_APPLE = 18
    DOUGHNUT = 19
    COFFEE = 20
    CHICKEN = 21
    LEMONADE = 22
    WATCHING = 23
    PRETZEL = 24
    SUNGLASSES = 25
    SUJEONGGWA = 26
    JUICE = 27
    FUNNEL_CAKE = 28
    NOODLES = 29
    SAUSAGE = 30
    SOUP = 31
    SANDWICH = 32
    INVALID = 255

class LitterType(IntEnum):
    VOMIT = 0
    VOMIT_ALT = 1
    EMPTY_CAN = 2
    RUBBISH = 3
    BURGER_BOX = 4
    EMPTY_CUP = 5
    EMPTY_BOX = 6
    EMPTY_BOTTLE = 7
    EMPTY_BOWL_RED = 8
    EMPTY_DRINK_CARTON = 9
    EMPTY_JUICE_CUP = 10
    EMPTY_BOWL_BLUE = 11

class StaffType(IntEnum):
    HANDYMAN = 0
    MECHANIC = 1
    SECURITY = 2
    ENTERTAINER = 3
    COUNT = 4

class RideType(IntEnum):
    SPIRAL_ROLLER_COASTER = 0
    STAND_UP_ROLLER_COASTER = 1
    SUSPENDED_SWINGING_COASTER = 2
    INVERTED_ROLLER_COASTER = 3
    JUNIOR_ROLLER_COASTER = 4
    MINIATURE_RAILWAY = 5
    MONORAIL = 6
    MINI_SUSPENDED_COASTER = 7
    BOAT_HIRE = 8
    WOODEN_WILD_MOUSE = 9
    STEEPLECHASE = 10
    CAR_RIDE = 11
    LAUNCHED_FREEFALL = 12
    BOBSLEIGH_COASTER = 13
    OBSERVATION_TOWER = 14
    LOOPING_ROLLER_COASTER = 15
    DINGHY_SLIDE = 16
    MINE_TRAIN_COASTER = 17
    CHAIRLIFT = 18
    CORKSCREW_ROLLER_COASTER = 19
    MAZE = 20
    SPIRAL_SLIDE = 21
    GO_KARTS = 22
    LOG_FLUME = 23
    RIVER_RAPIDS = 24
    DODGEMS = 25
    SWINGING_SHIP = 26
    SWINGING_INVERTER_SHIP = 27
    FOOD_STALL = 28
    DRINK_STALL = 30
    SHOP = 32
    MERRY_GO_ROUND = 33
    INFORMATION_KIOSK = 35
    TOILETS = 36
    FERRIS_WHEEL = 37
    MOTION_SIMULATOR = 38
    _3D_CINEMA = 39
    TOP_SPIN = 40
    SPACE_RINGS = 41
    REVERSE_FREEFALL_COASTER = 42
    LIFT = 43
    VERTICAL_DROP_ROLLER_COASTER = 44
    CASH_MACHINE = 45
    TWIST = 46
    HAUNTED_HOUSE = 47
    FIRST_AID = 48
    CIRCUS = 49
    GHOST_TRAIN = 50
    TWISTER_ROLLER_COASTER = 51
    WOODEN_ROLLER_COASTER = 52
    SIDE_FRICTION_ROLLER_COASTER = 53
    STEEL_WILD_MOUSE = 54
    MULTI_DIMENSION_ROLLER_COASTER = 55
    MULTI_DIMENSION_ROLLER_COASTER_ALT = 56
    FLYING_ROLLER_COASTER = 57
    FLYING_ROLLER_COASTER_ALT = 58
    VIRGINIA_REEL = 59
    SPLASH_BOATS = 60
    MINI_HELICOPTERS = 61
    LAY_DOWN_ROLLER_COASTER = 62
    SUSPENDED_MONORAIL = 63
    LAY_DOWN_ROLLER_COASTER_ALT = 64
    REVERSER_ROLLER_COASTER = 65
    HEARTLINE_TWISTER_COASTER = 66
    MINI_GOLF = 67
    GIGA_COASTER = 68
    ROTO_DROP = 69
    FLYING_SAUCERS = 70
    CROOKED_HOUSE = 71
    MONORAIL_CYCLES = 72
    COMPACT_INVERTED_COASTER = 73
    WATER_COASTER = 74
    AIR_POWERED_VERTICAL_COASTER = 75
    INVERTED_HAIRPIN_COASTER = 76
    MAGIC_CARPET = 77
    SUBMARINE_RIDE = 78
    RIVER_RAFTS = 79
    ENTERPRISE = 81
    INVERTED_IMPULSE_COASTER = 86
    MINI_ROLLER_COASTER = 87
    MINE_RIDE = 88
    LIM_LAUNCHED_ROLLER_COASTER = 90
    HYBRID_COASTER = 91
    SINGLE_RAIL_ROLLER_COASTER = 92
    ALPINE_COASTER = 93
    CLASSIC_WOODEN_ROLLER_COASTER = 94
    CLASSIC_STAND_UP_ROLLER_COASTER = 95
    LSM_LAUNCHED_ROLLER_COASTER = 96
    CLASSIC_WOODEN_TWISTER_ROLLER_COASTER = 97

class RideMode(IntEnum):
    NORMAL = 0
    CONTINUOUS_CIRCUIT = 1
    REVERSE_INCLINE_LAUNCHED_SHUTTLE = 2
    POWERED_LAUNCH_PASSTROUGH = 3
    SHUTTLE = 4
    BOAT_HIRE = 5
    UPWARD_LAUNCH = 6
    ROTATING_LIFT = 7
    STATION_TO_STATION = 8
    SINGLE_RIDE_PER_ADMISSION = 9
    UNLIMITED_RIDES_PER_ADMISSION = 10
    MAZE = 11
    RACE = 12
    DODGEMS = 13
    SWING = 14
    SHOP_STALL = 15
    ROTATION = 16
    FORWARD_ROTATION = 17
    BACKWARD_ROTATION = 18
    FILM_AVENGING_AVIATORS = 19
    MOUSE_TAILS3_DFILM = 20
    SPACE_RINGS = 21
    BEGINNERS = 22
    LIM_POWERED_LAUNCH = 23
    FILM_THRILL_RIDERS = 24
    STORM_CHASERS3_DFILM = 25
    SPACE_RAIDERS3_DFILM = 26
    INTENSE = 27
    BERSERK = 28
    HAUNTED_HOUSE = 29
    CIRCUS = 30
    DOWNWARD_LAUNCH = 31
    CROOKED_HOUSE = 32
    FREEFALL_DROP = 33
    CONTINUOUS_CIRCUIT_BLOCK_SECTIONED = 34
    POWERED_LAUNCH = 35
    POWERED_LAUNCH_BLOCK_SECTIONED = 36
    COUNT = 37
    NULL_MODE = 255

class RideInspection(IntEnum):
    EVERY10_MINUTES = 0
    EVERY20_MINUTES = 1
    EVERY30_MINUTES = 2
    EVERY45_MINUTES = 3
    EVERY_HOUR = 4
    EVERY2_HOURS = 5
    NEVER = 6

class RideStatus(IntEnum):
    CLOSED = 0
    OPEN = 1
    TESTING = 2
    SIMULATING = 3
    COUNT = 4

class ShopItem(IntEnum):
    BALLOON = 0
    TOY = 1
    MAP = 2
    PHOTO = 3
    UMBRELLA = 4
    DRINK = 5
    BURGER = 6
    CHIPS = 7
    ICE_CREAM = 8
    CANDYFLOSS = 9
    EMPTY_CAN = 10
    RUBBISH = 11
    EMPTY_BURGER_BOX = 12
    PIZZA = 13
    VOUCHER = 14
    POPCORN = 15
    HOT_DOG = 16
    TENTACLE = 17
    HAT = 18
    TOFFEE_APPLE = 19
    T_SHIRT = 20
    DOUGHNUT = 21
    COFFEE = 22
    EMPTY_CUP = 23
    CHICKEN = 24
    LEMONADE = 25
    EMPTY_BOX = 26
    EMPTY_BOTTLE = 27
    ADMISSION = 31
    PHOTO2 = 32
    PHOTO3 = 33
    PHOTO4 = 34
    PRETZEL = 35
    CHOCOLATE = 36
    ICED_TEA = 37
    FUNNEL_CAKE = 38
    SUNGLASSES = 39
    BEEF_NOODLES = 40
    FRIED_RICE_NOODLES = 41
    WONTON_SOUP = 42
    MEATBALL_SOUP = 43
    FRUIT_JUICE = 44
    SOYBEAN_MILK = 45
    SUJEONGGWA = 46
    SUB_SANDWICH = 47
    COOKIE = 48
    EMPTY_BOWL_RED = 49
    EMPTY_DRINK_CARTON = 50
    EMPTY_JUICE_CUP = 51
    ROAST_SAUSAGE = 52
    EMPTY_BOWL_BLUE = 53
    COUNT = 56
    NONE = 255

class TrackElemType(IntEnum):
    FLAT = 0
    END_STATION = 1
    BEGIN_STATION = 2
    MIDDLE_STATION = 3
    UP25 = 4
    UP60 = 5
    FLAT_TO_UP25 = 6
    UP25_TO_UP60 = 7
    UP60_TO_UP25 = 8
    UP25_TO_FLAT = 9
    DOWN25 = 10
    DOWN60 = 11
    FLAT_TO_DOWN25 = 12
    DOWN25_TO_DOWN60 = 13
    DOWN60_TO_DOWN25 = 14
    DOWN25_TO_FLAT = 15
    LEFT_QUARTER_TURN5_TILES = 16
    RIGHT_QUARTER_TURN5_TILES = 17
    FLAT_TO_LEFT_BANK = 18
    FLAT_TO_RIGHT_BANK = 19
    LEFT_BANK_TO_FLAT = 20
    RIGHT_BANK_TO_FLAT = 21
    BANKED_LEFT_QUARTER_TURN5_TILES = 22
    BANKED_RIGHT_QUARTER_TURN5_TILES = 23
    LEFT_BANK_TO_UP25 = 24
    RIGHT_BANK_TO_UP25 = 25
    UP25_TO_LEFT_BANK = 26
    UP25_TO_RIGHT_BANK = 27
    LEFT_BANK_TO_DOWN25 = 28
    RIGHT_BANK_TO_DOWN25 = 29
    DOWN25_TO_LEFT_BANK = 30
    DOWN25_TO_RIGHT_BANK = 31
    LEFT_BANK = 32
    RIGHT_BANK = 33
    LEFT_QUARTER_TURN5_TILES_UP25 = 34
    RIGHT_QUARTER_TURN5_TILES_UP25 = 35
    LEFT_QUARTER_TURN5_TILES_DOWN25 = 36
    RIGHT_QUARTER_TURN5_TILES_DOWN25 = 37
    S_BEND_LEFT = 38
    S_BEND_RIGHT = 39
    LEFT_VERTICAL_LOOP = 40
    RIGHT_VERTICAL_LOOP = 41
    LEFT_QUARTER_TURN3_TILES = 42
    RIGHT_QUARTER_TURN3_TILES = 43
    LEFT_BANKED_QUARTER_TURN3_TILES = 44
    RIGHT_BANKED_QUARTER_TURN3_TILES = 45
    LEFT_QUARTER_TURN3_TILES_UP25 = 46
    RIGHT_QUARTER_TURN3_TILES_UP25 = 47
    LEFT_QUARTER_TURN3_TILES_DOWN25 = 48
    RIGHT_QUARTER_TURN3_TILES_DOWN25 = 49
    LEFT_QUARTER_TURN1_TILE = 50
    RIGHT_QUARTER_TURN1_TILE = 51
    LEFT_TWIST_DOWN_TO_UP = 52
    RIGHT_TWIST_DOWN_TO_UP = 53
    LEFT_TWIST_UP_TO_DOWN = 54
    RIGHT_TWIST_UP_TO_DOWN = 55
    HALF_LOOP_UP = 56
    HALF_LOOP_DOWN = 57
    LEFT_CORKSCREW_UP = 58
    RIGHT_CORKSCREW_UP = 59
    LEFT_CORKSCREW_DOWN = 60
    RIGHT_CORKSCREW_DOWN = 61
    FLAT_TO_UP60 = 62
    UP60_TO_FLAT = 63
    FLAT_TO_DOWN60 = 64
    DOWN60_TO_FLAT = 65
    TOWER_BASE = 66
    TOWER_SECTION = 67
    FLAT_COVERED = 68
    UP25_COVERED = 69
    UP60_COVERED = 70
    FLAT_TO_UP25_COVERED = 71
    UP25_TO_UP60_COVERED = 72
    UP60_TO_UP25_COVERED = 73
    UP25_TO_FLAT_COVERED = 74
    DOWN25_COVERED = 75
    DOWN60_COVERED = 76
    FLAT_TO_DOWN25_COVERED = 77
    DOWN25_TO_DOWN60_COVERED = 78
    DOWN60_TO_DOWN25_COVERED = 79
    DOWN25_TO_FLAT_COVERED = 80
    LEFT_QUARTER_TURN5_TILES_COVERED = 81
    RIGHT_QUARTER_TURN5_TILES_COVERED = 82
    S_BEND_LEFT_COVERED = 83
    S_BEND_RIGHT_COVERED = 84
    LEFT_QUARTER_TURN3_TILES_COVERED = 85
    RIGHT_QUARTER_TURN3_TILES_COVERED = 86
    LEFT_HALF_BANKED_HELIX_UP_SMALL = 87
    RIGHT_HALF_BANKED_HELIX_UP_SMALL = 88
    LEFT_HALF_BANKED_HELIX_DOWN_SMALL = 89
    RIGHT_HALF_BANKED_HELIX_DOWN_SMALL = 90
    LEFT_HALF_BANKED_HELIX_UP_LARGE = 91
    RIGHT_HALF_BANKED_HELIX_UP_LARGE = 92
    LEFT_HALF_BANKED_HELIX_DOWN_LARGE = 93
    RIGHT_HALF_BANKED_HELIX_DOWN_LARGE = 94
    LEFT_QUARTER_TURN1_TILE_UP60 = 95
    RIGHT_QUARTER_TURN1_TILE_UP60 = 96
    LEFT_QUARTER_TURN1_TILE_DOWN60 = 97
    RIGHT_QUARTER_TURN1_TILE_DOWN60 = 98
    BRAKES = 99
    BOOSTER = 100
    MAZE = 101
    LEFT_QUARTER_BANKED_HELIX_LARGE_UP = 102
    RIGHT_QUARTER_BANKED_HELIX_LARGE_UP = 103
    LEFT_QUARTER_BANKED_HELIX_LARGE_DOWN = 104
    RIGHT_QUARTER_BANKED_HELIX_LARGE_DOWN = 105
    LEFT_QUARTER_HELIX_LARGE_UP = 106
    RIGHT_QUARTER_HELIX_LARGE_UP = 107
    LEFT_QUARTER_HELIX_LARGE_DOWN = 108
    RIGHT_QUARTER_HELIX_LARGE_DOWN = 109
    UP25_LEFT_BANKED = 110
    UP25_RIGHT_BANKED = 111
    WATERFALL = 112
    RAPIDS = 113
    ON_RIDE_PHOTO = 114
    DOWN25_LEFT_BANKED = 115
    DOWN25_RIGHT_BANKED = 116
    WATER_SPLASH = 117
    FLAT_TO_UP60_LONG_BASE = 118
    UP60_TO_FLAT_LONG_BASE = 119
    WHIRLPOOL = 120
    DOWN60_TO_FLAT_LONG_BASE = 121
    FLAT_TO_DOWN60_LONG_BASE = 122
    CABLE_LIFT_HILL = 123
    REVERSE_FREEFALL_SLOPE = 124
    REVERSE_FREEFALL_VERTICAL = 125
    UP90 = 126
    DOWN90 = 127
    UP60_TO_UP90 = 128
    DOWN90_TO_DOWN60 = 129
    UP90_TO_UP60 = 130
    DOWN60_TO_DOWN90 = 131
    BRAKE_FOR_DROP = 132
    LEFT_EIGHTH_TO_DIAG = 133
    RIGHT_EIGHTH_TO_DIAG = 134
    LEFT_EIGHTH_TO_ORTHOGONAL = 135
    RIGHT_EIGHTH_TO_ORTHOGONAL = 136
    LEFT_EIGHTH_BANK_TO_DIAG = 137
    RIGHT_EIGHTH_BANK_TO_DIAG = 138
    LEFT_EIGHTH_BANK_TO_ORTHOGONAL = 139
    RIGHT_EIGHTH_BANK_TO_ORTHOGONAL = 140
    DIAG_FLAT = 141
    DIAG_UP25 = 142
    DIAG_UP60 = 143
    DIAG_FLAT_TO_UP25 = 144
    DIAG_UP25_TO_UP60 = 145
    DIAG_UP60_TO_UP25 = 146
    DIAG_UP25_TO_FLAT = 147
    DIAG_DOWN25 = 148
    DIAG_DOWN60 = 149
    DIAG_FLAT_TO_DOWN25 = 150
    DIAG_DOWN25_TO_DOWN60 = 151
    DIAG_DOWN60_TO_DOWN25 = 152
    DIAG_DOWN25_TO_FLAT = 153
    DIAG_FLAT_TO_UP60 = 154
    DIAG_UP60_TO_FLAT = 155
    DIAG_FLAT_TO_DOWN60 = 156
    DIAG_DOWN60_TO_FLAT = 157
    DIAG_FLAT_TO_LEFT_BANK = 158
    DIAG_FLAT_TO_RIGHT_BANK = 159
    DIAG_LEFT_BANK_TO_FLAT = 160
    DIAG_RIGHT_BANK_TO_FLAT = 161
    DIAG_LEFT_BANK_TO_UP25 = 162
    DIAG_RIGHT_BANK_TO_UP25 = 163
    DIAG_UP25_TO_LEFT_BANK = 164
    DIAG_UP25_TO_RIGHT_BANK = 165
    DIAG_LEFT_BANK_TO_DOWN25 = 166
    DIAG_RIGHT_BANK_TO_DOWN25 = 167
    DIAG_DOWN25_TO_LEFT_BANK = 168
    DIAG_DOWN25_TO_RIGHT_BANK = 169
    DIAG_LEFT_BANK = 170
    DIAG_RIGHT_BANK = 171
    LOG_FLUME_REVERSER = 172
    SPINNING_TUNNEL = 173
    LEFT_BARREL_ROLL_UP_TO_DOWN = 174
    RIGHT_BARREL_ROLL_UP_TO_DOWN = 175
    LEFT_BARREL_ROLL_DOWN_TO_UP = 176
    RIGHT_BARREL_ROLL_DOWN_TO_UP = 177
    LEFT_BANK_TO_LEFT_QUARTER_TURN3_TILES_UP25 = 178
    RIGHT_BANK_TO_RIGHT_QUARTER_TURN3_TILES_UP25 = 179
    LEFT_QUARTER_TURN3_TILES_DOWN25_TO_LEFT_BANK = 180
    RIGHT_QUARTER_TURN3_TILES_DOWN25_TO_RIGHT_BANK = 181
    POWERED_LIFT = 182
    LEFT_LARGE_HALF_LOOP_UP = 183
    RIGHT_LARGE_HALF_LOOP_UP = 184
    LEFT_LARGE_HALF_LOOP_DOWN = 185
    RIGHT_LARGE_HALF_LOOP_DOWN = 186
    LEFT_FLYER_TWIST_UP = 187
    RIGHT_FLYER_TWIST_UP = 188
    LEFT_FLYER_TWIST_DOWN = 189
    RIGHT_FLYER_TWIST_DOWN = 190
    FLYER_HALF_LOOP_UNINVERTED_UP = 191
    FLYER_HALF_LOOP_INVERTED_DOWN = 192
    LEFT_FLYER_CORKSCREW_UP = 193
    RIGHT_FLYER_CORKSCREW_UP = 194
    LEFT_FLYER_CORKSCREW_DOWN = 195
    RIGHT_FLYER_CORKSCREW_DOWN = 196
    HEART_LINE_TRANSFER_UP = 197
    HEART_LINE_TRANSFER_DOWN = 198
    LEFT_HEART_LINE_ROLL = 199
    RIGHT_HEART_LINE_ROLL = 200
    MINIGOLF_HOLE_A = 201
    MINIGOLF_HOLE_B = 202
    MINIGOLF_HOLE_C = 203
    MINIGOLF_HOLE_D = 204
    MINIGOLF_HOLE_E = 205
    MULTI_DIM_INVERTED_FLAT_TO_DOWN90_QUARTER_LOOP = 206
    UP90_TO_INVERTED_FLAT_QUARTER_LOOP = 207
    INVERTED_FLAT_TO_DOWN90_QUARTER_LOOP = 208
    LEFT_CURVED_LIFT_HILL = 209
    RIGHT_CURVED_LIFT_HILL = 210
    LEFT_REVERSER = 211
    RIGHT_REVERSER = 212
    AIR_THRUST_TOP_CAP = 213
    AIR_THRUST_VERTICAL_DOWN = 214
    AIR_THRUST_VERTICAL_DOWN_TO_LEVEL = 215
    BLOCK_BRAKES = 216
    LEFT_BANKED_QUARTER_TURN3_TILE_UP25 = 217
    RIGHT_BANKED_QUARTER_TURN3_TILE_UP25 = 218
    LEFT_BANKED_QUARTER_TURN3_TILE_DOWN25 = 219
    RIGHT_BANKED_QUARTER_TURN3_TILE_DOWN25 = 220
    LEFT_BANKED_QUARTER_TURN5_TILE_UP25 = 221
    RIGHT_BANKED_QUARTER_TURN5_TILE_UP25 = 222
    LEFT_BANKED_QUARTER_TURN5_TILE_DOWN25 = 223
    RIGHT_BANKED_QUARTER_TURN5_TILE_DOWN25 = 224
    UP25_TO_LEFT_BANKED_UP25 = 225
    UP25_TO_RIGHT_BANKED_UP25 = 226
    LEFT_BANKED_UP25_TO_UP25 = 227
    RIGHT_BANKED_UP25_TO_UP25 = 228
    DOWN25_TO_LEFT_BANKED_DOWN25 = 229
    DOWN25_TO_RIGHT_BANKED_DOWN25 = 230
    LEFT_BANKED_DOWN25_TO_DOWN25 = 231
    RIGHT_BANKED_DOWN25_TO_DOWN25 = 232
    LEFT_BANKED_FLAT_TO_LEFT_BANKED_UP25 = 233
    RIGHT_BANKED_FLAT_TO_RIGHT_BANKED_UP25 = 234
    LEFT_BANKED_UP25_TO_LEFT_BANKED_FLAT = 235
    RIGHT_BANKED_UP25_TO_RIGHT_BANKED_FLAT = 236
    LEFT_BANKED_FLAT_TO_LEFT_BANKED_DOWN25 = 237
    RIGHT_BANKED_FLAT_TO_RIGHT_BANKED_DOWN25 = 238
    LEFT_BANKED_DOWN25_TO_LEFT_BANKED_FLAT = 239
    RIGHT_BANKED_DOWN25_TO_RIGHT_BANKED_FLAT = 240
    FLAT_TO_LEFT_BANKED_UP25 = 241
    FLAT_TO_RIGHT_BANKED_UP25 = 242
    LEFT_BANKED_UP25_TO_FLAT = 243
    RIGHT_BANKED_UP25_TO_FLAT = 244
    FLAT_TO_LEFT_BANKED_DOWN25 = 245
    FLAT_TO_RIGHT_BANKED_DOWN25 = 246
    LEFT_BANKED_DOWN25_TO_FLAT = 247
    RIGHT_BANKED_DOWN25_TO_FLAT = 248
    LEFT_QUARTER_TURN1_TILE_UP90 = 249
    RIGHT_QUARTER_TURN1_TILE_UP90 = 250
    LEFT_QUARTER_TURN1_TILE_DOWN90 = 251
    RIGHT_QUARTER_TURN1_TILE_DOWN90 = 252
    MULTI_DIM_UP90_TO_INVERTED_FLAT_QUARTER_LOOP = 253
    MULTI_DIM_FLAT_TO_DOWN90_QUARTER_LOOP = 254
    MULTI_DIM_INVERTED_UP90_TO_FLAT_QUARTER_LOOP = 255
    ROTATION_CONTROL_TOGGLE = 256
    FLAT_TRACK1X4_A = 257
    FLAT_TRACK2X2 = 258
    FLAT_TRACK4X4 = 259
    FLAT_TRACK2X4 = 260
    FLAT_TRACK1X5 = 261
    FLAT_TRACK1X1_A = 262
    FLAT_TRACK1X4_B = 263
    FLAT_TRACK1X1_B = 264
    FLAT_TRACK1X4_C = 265
    FLAT_TRACK3X3 = 266
    HIGHEST_ALIAS = 266
    LEFT_LARGE_CORKSCREW_UP = 267
    RIGHT_LARGE_CORKSCREW_UP = 268
    LEFT_LARGE_CORKSCREW_DOWN = 269
    RIGHT_LARGE_CORKSCREW_DOWN = 270
    LEFT_MEDIUM_HALF_LOOP_UP = 271
    RIGHT_MEDIUM_HALF_LOOP_UP = 272
    LEFT_MEDIUM_HALF_LOOP_DOWN = 273
    RIGHT_MEDIUM_HALF_LOOP_DOWN = 274
    LEFT_ZERO_GROLL_UP = 275
    RIGHT_ZERO_GROLL_UP = 276
    LEFT_ZERO_GROLL_DOWN = 277
    RIGHT_ZERO_GROLL_DOWN = 278
    LEFT_LARGE_ZERO_GROLL_UP = 279
    RIGHT_LARGE_ZERO_GROLL_UP = 280
    LEFT_LARGE_ZERO_GROLL_DOWN = 281
    RIGHT_LARGE_ZERO_GROLL_DOWN = 282
    LEFT_FLYER_LARGE_HALF_LOOP_UNINVERTED_UP = 283
    RIGHT_FLYER_LARGE_HALF_LOOP_UNINVERTED_UP = 284
    LEFT_FLYER_LARGE_HALF_LOOP_INVERTED_DOWN = 285
    RIGHT_FLYER_LARGE_HALF_LOOP_INVERTED_DOWN = 286
    LEFT_FLYER_LARGE_HALF_LOOP_INVERTED_UP = 287
    RIGHT_FLYER_LARGE_HALF_LOOP_INVERTED_UP = 288
    LEFT_FLYER_LARGE_HALF_LOOP_UNINVERTED_DOWN = 289
    RIGHT_FLYER_LARGE_HALF_LOOP_UNINVERTED_DOWN = 290
    FLYER_HALF_LOOP_INVERTED_UP = 291
    FLYER_HALF_LOOP_UNINVERTED_DOWN = 292
    LEFT_EIGHTH_TO_DIAG_UP25 = 293
    RIGHT_EIGHTH_TO_DIAG_UP25 = 294
    LEFT_EIGHTH_TO_DIAG_DOWN25 = 295
    RIGHT_EIGHTH_TO_DIAG_DOWN25 = 296
    LEFT_EIGHTH_TO_ORTHOGONAL_UP25 = 297
    RIGHT_EIGHTH_TO_ORTHOGONAL_UP25 = 298
    LEFT_EIGHTH_TO_ORTHOGONAL_DOWN25 = 299
    RIGHT_EIGHTH_TO_ORTHOGONAL_DOWN25 = 300
    DIAG_UP25_TO_LEFT_BANKED_UP25 = 301
    DIAG_UP25_TO_RIGHT_BANKED_UP25 = 302
    DIAG_LEFT_BANKED_UP25_TO_UP25 = 303
    DIAG_RIGHT_BANKED_UP25_TO_UP25 = 304
    DIAG_DOWN25_TO_LEFT_BANKED_DOWN25 = 305
    DIAG_DOWN25_TO_RIGHT_BANKED_DOWN25 = 306
    DIAG_LEFT_BANKED_DOWN25_TO_DOWN25 = 307
    DIAG_RIGHT_BANKED_DOWN25_TO_DOWN25 = 308
    DIAG_LEFT_BANKED_FLAT_TO_LEFT_BANKED_UP25 = 309
    DIAG_RIGHT_BANKED_FLAT_TO_RIGHT_BANKED_UP25 = 310
    DIAG_LEFT_BANKED_UP25_TO_LEFT_BANKED_FLAT = 311
    DIAG_RIGHT_BANKED_UP25_TO_RIGHT_BANKED_FLAT = 312
    DIAG_LEFT_BANKED_FLAT_TO_LEFT_BANKED_DOWN25 = 313
    DIAG_RIGHT_BANKED_FLAT_TO_RIGHT_BANKED_DOWN25 = 314
    DIAG_LEFT_BANKED_DOWN25_TO_LEFT_BANKED_FLAT = 315
    DIAG_RIGHT_BANKED_DOWN25_TO_RIGHT_BANKED_FLAT = 316
    DIAG_FLAT_TO_LEFT_BANKED_UP25 = 317
    DIAG_FLAT_TO_RIGHT_BANKED_UP25 = 318
    DIAG_LEFT_BANKED_UP25_TO_FLAT = 319
    DIAG_RIGHT_BANKED_UP25_TO_FLAT = 320
    DIAG_FLAT_TO_LEFT_BANKED_DOWN25 = 321
    DIAG_FLAT_TO_RIGHT_BANKED_DOWN25 = 322
    DIAG_LEFT_BANKED_DOWN25_TO_FLAT = 323
    DIAG_RIGHT_BANKED_DOWN25_TO_FLAT = 324
    DIAG_UP25_LEFT_BANKED = 325
    DIAG_UP25_RIGHT_BANKED = 326
    DIAG_DOWN25_LEFT_BANKED = 327
    DIAG_DOWN25_RIGHT_BANKED = 328
    LEFT_EIGHTH_BANK_TO_DIAG_UP25 = 329
    RIGHT_EIGHTH_BANK_TO_DIAG_UP25 = 330
    LEFT_EIGHTH_BANK_TO_DIAG_DOWN25 = 331
    RIGHT_EIGHTH_BANK_TO_DIAG_DOWN25 = 332
    LEFT_EIGHTH_BANK_TO_ORTHOGONAL_UP25 = 333
    RIGHT_EIGHTH_BANK_TO_ORTHOGONAL_UP25 = 334
    LEFT_EIGHTH_BANK_TO_ORTHOGONAL_DOWN25 = 335
    RIGHT_EIGHTH_BANK_TO_ORTHOGONAL_DOWN25 = 336
    DIAG_BRAKES = 337
    DIAG_BLOCK_BRAKES = 338
    DOWN25_BRAKES = 339
    DIAG_BOOSTER = 340
    DIAG_FLAT_TO_UP60_LONG_BASE = 341
    DIAG_UP60_TO_FLAT_LONG_BASE = 342
    DIAG_FLAT_TO_DOWN60_LONG_BASE = 343
    DIAG_DOWN60_TO_FLAT_LONG_BASE = 344
    LEFT_EIGHTH_DIVE_LOOP_UP_TO_ORTHOGONAL = 345
    RIGHT_EIGHTH_DIVE_LOOP_UP_TO_ORTHOGONAL = 346
    LEFT_EIGHTH_DIVE_LOOP_DOWN_TO_DIAG = 347
    RIGHT_EIGHTH_DIVE_LOOP_DOWN_TO_DIAG = 348
    DIAG_DOWN25_BRAKES = 349
    COUNT = 350
    NONE = 65535

class TrackRoll(IntEnum):
    NONE = 0
    LEFT = 2
    RIGHT = 4
    UPSIDE_DOWN = 15

class TrackPitch(IntEnum):
    NONE = 0
    UP25 = 2
    UP60 = 4
    DOWN25 = 6
    DOWN60 = 8
    UP90 = 10
    DOWN90 = 18
    TOWER = 10
    REVERSE_FREEFALL = 10

class TrackCurve(IntEnum):
    LEFT_VERY_SMALL = 5
    LEFT_SMALL = 3
    LEFT = 1
    LEFT_LARGE = 7
    NONE = 0
    RIGHT_LARGE = 8
    RIGHT = 2
    RIGHT_SMALL = 4
    RIGHT_VERY_SMALL = 6

class Colour(IntEnum):
    BLACK = 0
    GREY = 1
    WHITE = 2
    DARK_PURPLE = 3
    LIGHT_PURPLE = 4
    BRIGHT_PURPLE = 5
    DARK_BLUE = 6
    LIGHT_BLUE = 7
    ICY_BLUE = 8
    DARK_WATER = 9
    LIGHT_WATER = 10
    SATURATED_GREEN = 11
    DARK_GREEN = 12
    MOSS_GREEN = 13
    BRIGHT_GREEN = 14
    OLIVE_GREEN = 15
    DARK_OLIVE_GREEN = 16
    BRIGHT_YELLOW = 17
    YELLOW = 18
    DARK_YELLOW = 19
    LIGHT_ORANGE = 20
    DARK_ORANGE = 21
    LIGHT_BROWN = 22
    SATURATED_BROWN = 23
    DARK_BROWN = 24
    SALMON_PINK = 25
    BORDEAUX_RED = 26
    SATURATED_RED = 27
    BRIGHT_RED = 28
    DARK_PINK = 29
    BRIGHT_PINK = 30
    LIGHT_PINK = 31
    ARMY_GREEN = 32
    HONEY_DEW = 33
    TAN = 34
    MAROON = 35
    CORAL_PINK = 36
    FOREST_GREEN = 37
    CHARTREUSE = 38
    HUNTER_GREEN = 39
    CELADON = 40
    LIME_GREEN = 41
    SEPIA = 42
    PEACH = 43
    PERIWINKLE = 44
    VIRIDIAN = 45
    SEAFOAM_GREEN = 46
    VIOLET = 47
    LAVENDER = 48
    PASTEL_ORANGE = 49
    DEEP_WATER = 50
    PASTEL_PINK = 51
    UMBER = 52
    BEIGE = 53
    INVISIBLE = 54
    VOID_BACKGROUND = 55

class CheatType(IntEnum):
    SANDBOX_MODE = 0
    DISABLE_CLEARANCE_CHECKS = 1
    DISABLE_SUPPORT_LIMITS = 2
    SHOW_ALL_OPERATING_MODES = 3
    SHOW_VEHICLES_FROM_OTHER_TRACK_TYPES = 4
    DISABLE_TRAIN_LENGTH_LIMIT = 5
    ENABLE_CHAIN_LIFT_ON_ALL_TRACK = 6
    FAST_LIFT_HILL = 7
    DISABLE_BRAKES_FAILURE = 8
    DISABLE_ALL_BREAKDOWNS = 9
    UNLOCK_ALL_PRICES = 10
    BUILD_IN_PAUSE_MODE = 11
    IGNORE_RIDE_INTENSITY = 12
    DISABLE_VANDALISM = 13
    DISABLE_LITTERING = 14
    NO_MONEY = 15
    ADD_MONEY = 16
    SET_MONEY = 17
    CLEAR_LOAN = 18
    SET_GUEST_PARAMETER = 19
    GENERATE_GUESTS = 20
    REMOVE_ALL_GUESTS = 21
    GIVE_ALL_GUESTS = 22
    SET_GRASS_LENGTH = 23
    WATER_PLANTS = 24
    DISABLE_PLANT_AGING = 25
    FIX_VANDALISM = 26
    REMOVE_LITTER = 27
    SET_STAFF_SPEED = 28
    RENEW_RIDES = 29
    MAKE_DESTRUCTIBLE = 30
    FIX_RIDES = 31
    RESET_CRASH_STATUS = 32
    TEN_MINUTE_INSPECTIONS = 33
    WIN_SCENARIO = 34
    FORCE_WEATHER = 35
    FREEZE_WEATHER = 36
    OPEN_CLOSE_PARK = 37
    HAVE_FUN = 38
    SET_FORCED_PARK_RATING = 39
    NEVERENDING_MARKETING = 40
    ALLOW_ARBITRARY_RIDE_TYPE_CHANGES = 41
    OWN_ALL_LAND = 42
    DISABLE_RIDE_VALUE_AGING = 43
    IGNORE_RESEARCH_STATUS = 44
    ENABLE_ALL_DRAWABLE_TRACK_PIECES = 45
    CREATE_DUCKS = 46
    REMOVE_DUCKS = 47
    ALLOW_TRACK_PLACE_INVALID_HEIGHTS = 48
    NO_CAP_ON_QUEUE_LENGTH_DUMMY = 49
    ALLOW_REGULAR_PATH_AS_QUEUE = 50
    ALLOW_SPECIAL_COLOUR_SCHEMES = 51
    REMOVE_PARK_FENCES = 52
    IGNORE_PRICE = 53
    COUNT = 54

class RideSetSetting(IntEnum):
    MODE = 0
    DEPARTURE = 1
    MIN_WAITING_TIME = 2
    MAX_WAITING_TIME = 3
    OPERATION = 4
    INSPECTION_INTERVAL = 5
    MUSIC = 6
    MUSIC_TYPE = 7
    LIFT_HILL_SPEED = 8
    NUM_CIRCUITS = 9
    RIDE_TYPE = 10

class RideSetAppearanceType(IntEnum):
    TRACK_COLOUR_MAIN = 0
    TRACK_COLOUR_ADDITIONAL = 1
    TRACK_COLOUR_SUPPORTS = 2
    MAZE_STYLE = 2
    VEHICLE_COLOUR_BODY = 3
    VEHICLE_COLOUR_TRIM = 4
    VEHICLE_COLOUR_TERTIARY = 5
    VEHICLE_COLOUR_SCHEME = 6
    ENTRANCE_STYLE = 7
    SELLING_ITEM_COLOUR_IS_RANDOM = 8

class RideSetVehicleType(IntEnum):
    NUM_TRAINS = 0
    NUM_CARS_PER_TRAIN = 1
    RIDE_ENTRY = 2
    TRAINS_REVERSED = 3
    COUNT = 4

class RideModifyType(IntEnum):
    DEMOLISH = 0
    RENEW = 1

class RideRatingType(IntEnum):
    EXCITEMENT = 0
    INTENSITY = 1
    NAUSEA = 2

class BannerSetStyleType(IntEnum):
    PRIMARY_COLOUR = 0
    TEXT_COLOUR = 1
    NO_ENTRY = 2
    COUNT = 3

class LandBuyRightSetting(IntEnum):
    BUY_LAND = 0
    BUY_CONSTRUCTION_RIGHTS = 1
    COUNT = 2

class LandSetRightSetting(IntEnum):
    UNOWN_LAND = 0
    UNOWN_CONSTRUCTION_RIGHTS = 1
    SET_FOR_SALE = 2
    SET_CONSTRUCTION_RIGHTS_FOR_SALE = 3
    SET_OWNERSHIP_WITH_CHECKS = 4
    COUNT = 5

class MazeBuildMode(IntEnum):
    BUILD = 0
    MOVE = 1
    FILL = 2

class PeepPickupType(IntEnum):
    PICKUP = 0
    CANCEL = 1
    PLACE = 2
    COUNT = 3

class TileModifyType(IntEnum):
    ANY_REMOVE = 0
    ANY_SWAP = 1
    ANY_TOGGLE_INVISILIBITY = 2
    ANY_ROTATE = 3
    ANY_PASTE = 4
    ANY_SORT = 5
    ANY_BASE_HEIGHT_OFFSET = 6
    SURFACE_SHOW_PARK_FENCES = 7
    SURFACE_TOGGLE_CORNER = 8
    SURFACE_TOGGLE_DIAGONAL = 9
    PATH_SET_SLOPE = 10
    PATH_SET_BROKEN = 11
    PATH_TOGGLE_EDGE = 12
    PATH_SET_JUNCTION_RAILINGS = 13
    ENTRANCE_MAKE_USABLE = 14
    WALL_SET_SLOPE = 15
    WALL_SET_ANIMATION_FRAME = 16
    TRACK_BASE_HEIGHT_OFFSET = 17
    TRACK_SET_CHAIN = 18
    TRACK_SET_CHAIN_BLOCK = 19
    TRACK_SET_BRAKE = 20
    TRACK_SET_INDESTRUCTIBLE = 21
    SCENERY_SET_QUARTER_LOCATION = 22
    SCENERY_SET_QUARTER_COLLISION = 23
    BANNER_TOGGLE_BLOCKING_EDGE = 24
    WALL_SET_ANIMATION_IS_BACKWARDS = 25
    COUNT = 26

class ParkParameter(IntEnum):
    CLOSE = 0
    OPEN = 1
    SAME_PRICE_IN_PARK = 2
    COUNT = 3

class ScenarioSetSetting(IntEnum):
    NO_MONEY = 0
    INITIAL_CASH = 1
    INITIAL_LOAN = 2
    MAXIMUM_LOAN_SIZE = 3
    ANNUAL_INTEREST_RATE = 4
    FORBID_MARKETING_CAMPAIGNS = 5
    AVERAGE_CASH_PER_GUEST = 6
    GUEST_INITIAL_HAPPINESS = 7
    GUEST_INITIAL_HUNGER = 8
    GUEST_INITIAL_THIRST = 9
    GUESTS_PREFER_LESS_INTENSE_RIDES = 10
    GUESTS_PREFER_MORE_INTENSE_RIDES = 11
    COST_TO_BUY_LAND = 12
    COST_TO_BUY_CONSTRUCTION_RIGHTS = 13
    PARK_CHARGE_METHOD = 14
    PARK_CHARGE_ENTRY_FEE = 15
    FORBID_TREE_REMOVAL = 16
    FORBID_LANDSCAPE_CHANGES = 17
    FORBID_HIGH_CONSTRUCTION = 18
    PARK_RATING_HIGHER_DIFFICULTY_LEVEL = 19
    GUEST_GENERATION_HIGHER_DIFFICULTY_LEVEL = 20
    ALLOW_EARLY_COMPLETION = 21
    USE_RCT1_INTEREST = 22
    COUNT = 23

class LoadOrQuitModes(IntEnum):
    OPEN_SAVE_PROMPT = 0
    CLOSE_SAVE_PROMPT = 1

class StaffSetPatrolAreaMode(IntEnum):
    SET = 0
    UNSET = 1
    CLEAR_ALL = 2

class ModifyGroupType(IntEnum):
    ADD_GROUP = 0
    REMOVE_GROUP = 1
    SET_PERMISSIONS = 2
    SET_NAME = 3
    SET_DEFAULT = 4
    COUNT = 5

class PermissionState(IntEnum):
    TOGGLE = 0
    SET_ALL = 1
    CLEAR_ALL = 2
    COUNT = 3

class MapSelectType(IntEnum):
    CORNER0 = 0
    CORNER1 = 1
    CORNER2 = 2
    CORNER3 = 3
    FULL = 4
    FULL_WATER = 5
    FULL_LAND_RIGHTS = 6
    QUARTER0 = 7
    QUARTER1 = 8
    QUARTER2 = 9
    QUARTER3 = 10
    EDGE0 = 11
    EDGE1 = 12
    EDGE2 = 13
    EDGE3 = 14

class FootpathSlopeType(IntEnum):
    FLAT = 0
    SLOPED = 1
    RAISE = 2
    IRREGULAR = 3

class PromptMode(IntEnum):
    SAVE_BEFORE_LOAD = 0
    SAVE_BEFORE_QUIT = 1
    SAVE_BEFORE_QUIT2 = 2
    SAVE_BEFORE_NEW_GAME = 3
    QUIT = 4

class Direction(IntEnum):
    WEST = 0
    NORTH = 1
    EAST = 2
    SOUTH = 3

class ClearableItems(IntFlag):
    SCENERY_SMALL = 1
    SCENERY_LARGE = 2
    SCENERY_FOOTPATH = 4

class PathConstructFlags(IntFlag):
    IS_QUEUE = 1
    IS_LEGACY_PATH_OBJECT = 2

class SelectedLiftAndInverted(IntFlag):
    LIFT_HILL = 1
    INVERTED = 2

class AdvertisingCampaignType(IntEnum):
    PARK_ENTRY_FREE = 0
    RIDE_FREE = 1
    PARK_ENTRY_HALF_PRICE = 2
    FOOD_OR_DRINK_FREE = 3
    PARK = 4
    RIDE = 5

class ResearchFundingLevel(IntEnum):
    NONE = 0
    MINIMUM = 1
    NORMAL = 2
    MAXIMUM = 3

class GameSpeed(IntEnum):
    NORMAL = 1
    FAST = 2
    FASTER = 3
    FASTEST = 4
